import React, { useEffect } from 'react';
import { View, Text, StyleSheet, TouchableOpacity, Image, StatusBar, Linking, Platform } from 'react-native';
import { AMapSdk, MapView, Marker, MapType } from 'react-native-amap3d';
import { init, Geolocation } from 'react-native-amap-geolocation';
import { rpx } from '../../utils/rpx';
import { useNavigation } from '@react-navigation/native';

const DeviceMap = () => {
  const navigation = useNavigation();
  const latitude = 26.95500669;
  const longitude = 120.32736769;
  const imageUrl = "https://lxnapi.ccttiot.com/bike/img/static/uRx1B8B8acbquF2TO7Ry";
  
  const [userLocation, setUserLocation] = React.useState({
    latitude: 0,
    longitude: 0,
  });

  useEffect(() => {
    // 初始化定位
    async function initGeolocation() {
      await init({
        ios: "812efd3a950ba3675f928630302c6463",
        android: "812efd3a950ba3675f928630302c6463"
      });
      
      Geolocation.getCurrentPosition(
        ({ coords }) => {
          // console.log('定位错误:', coords);
          setUserLocation({
            latitude: coords.latitude,
            longitude: coords.longitude,
          });
        },
        (error) => {
          console.log('定位错误:', error);
        },
        // {
        //   timeout: 15000,
        //   maximumAge: 10000,
        //   distanceFilter: 100,
        // }
      );
    }

    initGeolocation();

    // 组件卸载时清理
    return () => {
      Geolocation.stop();
    };
  }, []);

  // 跳转到高德地图 
  const openAMap = async () => {
    const url = Platform.select({
      android: `androidamap://navi?sourceApplication=appname&lat=${latitude}&lon=${longitude}&dev=0&style=2`,
      ios: `iosamap://navi?sourceApplication=appname&lat=${latitude}&lon=${longitude}&dev=0&style=2`,
    });

    const fallbackUrl = `https://uri.amap.com/navigation?to=${longitude},${latitude},目的地&mode=car&coordinate=gaode`;

    try {
      // 检查是否安装了高德地图
      const supported = await Linking.canOpenURL(url);
      
      if (supported) {
        await Linking.openURL(url);
      } else {
        // 如果没有安装高德地图，则打开网页版
        await Linking.openURL(fallbackUrl);
      }
    } catch (error) {
      console.error('无法打开高德地图:', error);
      // 打开网页版作为后备方案
      await Linking.openURL(fallbackUrl);
    }
  };

  return (
    <View style={styles.container}>
      <StatusBar
        backgroundColor="#FFFFFF"
        barStyle="dark-content"
        translucent={false}
      />
      <MapView
        style={styles.map}
        mapType={MapType.Standard}
        zoomControlsEnabled={false}
        scrollEnabled={true}
        zoomEnabled={true}
        initialCameraPosition={{
          target: {
            latitude,
            longitude,
          },
          zoom: 15,
        }}
      >
        {/* 设备位置标记 */}
        <Marker
          position={{
            latitude,
            longitude,
          }}
          icon={{ uri: imageUrl }}
        />
        
        {/* 用户位置标记 */}
        {userLocation.latitude !== 0 && (
          <Marker
            position={{
              latitude: userLocation.latitude,
              longitude: userLocation.longitude,
            }}
            icon={{ uri: 'imageUrl' }}
          />
        )}
      </MapView>
      <View style={styles.bottomCard}>
        <View style={styles.addressInfo}>
          <Text style={styles.addressText}>
            福建省宁德市福鼎市海滨路200号靠近福鼎第四中学
          </Text>
          <Image 
            source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/voice' }}
            style={styles.voiceIcon}
          />
        </View>
        <TouchableOpacity 
          style={styles.navigationButton}
          onPress={openAMap}
        >
          <Text style={styles.buttonText}>导航到车辆</Text>
        </TouchableOpacity>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#FFFFFF',
  },
  map: {
    flex: 1,
    width: '100%',
  },
  header: {
    position: 'absolute',
    top: 0,
    left: 0,
    right: 0,
    height: rpx(88),
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    paddingHorizontal: rpx(32),
    backgroundColor: 'transparent',
  },
  backButton: {
    width: rpx(44),
    height: rpx(44),
    justifyContent: 'center',
    alignItems: 'center',
  },
  backIcon: {
    width: rpx(32),
    height: rpx(32),
  },
  timeContainer: {
    flex: 1,
    alignItems: 'center',
  },
  timeText: {
    fontSize: rpx(28),
    color: '#333333',
  },
  menuButton: {
    width: rpx(44),
    height: rpx(44),
    justifyContent: 'center',
    alignItems: 'center',
  },
  menuIcon: {
    width: rpx(32),
    height: rpx(32),
  },
  bottomCard: {
    position: 'absolute',
    bottom: 0,
    left: 0,
    right: 0,
    backgroundColor: '#FFFFFF',
    borderTopLeftRadius: rpx(24),
    borderTopRightRadius: rpx(24),
    padding: rpx(32),
  },
  addressInfo: {
    flexDirection: 'row',
    alignItems: 'center',
    marginBottom: rpx(32),
  },
  addressText: {
    flex: 1,
    fontSize: rpx(28),
    color: '#333333',
    marginRight: rpx(16),
  },
  voiceIcon: {
    width: rpx(44),
    height: rpx(44),
  },
  navigationButton: {
    height: rpx(96),
    backgroundColor: '#2089FF',
    borderRadius: rpx(48),
    justifyContent: 'center',
    alignItems: 'center',
  },
  buttonText: {
    fontSize: rpx(32),
    color: '#FFFFFF',
    fontWeight: '500',
  },
});

export default DeviceMap;